///////////////
// on windows systems this file is need when compiling migrate
// using the libharu PDF-package.
//
// Michal Palzcewski and Peter Beerli 2005
#ifdef WIN32
#include <new.h>
extern "C" {
  void set_haru_handler(void);
}
extern int throw_new_handler(size_t t);
void set_haru_handler() {
  _set_new_handler(throw_new_handler);
}
#endif

int dummy_function(int do_nothing)
{
  print("Some computer fail to compile MIGRATE with empty files\n");
  return 0;
}
